/*
    Copyright 2005,2006 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl.txt

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifndef WIN32
    #define strnicmp    strncasecmp
#endif



#define VER         "0.1"
#define BUFFSZ      2048



void bf2fra_pwd(char *pwd);
void std_err(void);



int main(int argc, char *argv[]) {
    FILE    *fd;
    char    buff[BUFFSZ + 1],
            *p;


    setbuf(stdout, NULL);

    fputs("\n"
        "Battlefield 2 Remote Administrator (BF2RA) password decoder "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(argc < 2) {
        printf("\n"
            "Usage: %s <settings.ini>\n"
            "\n", argv[0]);
        fputs("\n    Press RETURN to exit\n", stdout);
        fgetc(stdin);
        exit(1);
    }

    printf("- open file %s\n\n", argv[1]);
    fd = fopen(argv[1], "rb");
    if(!fd) std_err();

    while(fgets(buff, sizeof(buff), fd)) {
        for(p = buff; *p && (*p != '\r') && (*p != '\n'); p++);
        *p = 0;

        if(!strnicmp(buff, "password=", 9)) {
            bf2fra_pwd(buff + 9);
            printf("Password:   %s\n", buff + 9);
            break;
        }
    }

    fclose(fd);
    fputs("\n    Press RETURN to exit\n", stdout);
    fgetc(stdin);
    return(0);
}



void bf2fra_pwd(char *pwd) {
    const static char   enc[] = "7x21zoom8675309";
    char    *p;

    for(p = enc; *pwd; pwd++) {
        *pwd = (*pwd & 0xf0) | ((*pwd & 0xf) ^ (*p & 0xf));
        p++;
        if(!*p) p = enc;
    }
}



void std_err(void) {
    perror("\nError");
    fputs("\n    Press RETURN to exit\n", stdout);
    fgetc(stdin);
    exit(1);
}


